@@ -347,7 +347,7 @@ class MSData:
         """
 
         # check if BPC data is ready
-        if len(self.rtBPC) is None:
+        if self.rtBPC is None:
             self.getBPCData()
 
         plt.figure(figsize=figsize, dpi=dpi)
